{ lib     ? import <nixpkgs/lib>
, pkgsFun ? import <nixpkgs>
}:
let
  nixpkgsArgs = { config.allowNonSource = false; };
  nixpkgsOnBuildForBuild  = pkgsFun nixpkgsArgs;

  ownerboot = { hostPlatform?null, overlays }: let
    base = final: prev: {
      inherit hostPlatform;
      nixpkgsOnBuildForHost = pkgsFun
        (nixpkgsArgs
         // (lib.optionalAttrs (final.hostPlatform!=null) {
           crossSystem = final.hostPlatform;
         }));

      coreboot-toolchain = final.callPackage ./coreboot-toolchain { };

      iasl_20180531 = final.nixpkgsOnBuildForBuild.callPackage ./coreboot/iasl_20180531 { };
      coreboot      = final.callPackage ./coreboot {
        initramfs_image = final.initramfs;
      };
      kernel        = final.callPackage ./kernel { };
      userspace     = final.callPackage ./userspace { };
      initramfs     = final.callPackage ./initramfs { };
    };
  in
    (lib.makeScope
      lib.callPackageWith
      (self: { inherit lib nixpkgsOnBuildForBuild; })).overrideScope'
      (lib.foldl' lib.composeExtensions (_: prev: prev) ([base] ++ overlays));

in {
  # one entry for each supported platform
  kevin = ownerboot (import ./platform/kevin { inherit lib; });
  am1i  = ownerboot (import ./platform/am1i { inherit lib; });
  kgpe  = ownerboot (import ./platform/kgpe { inherit lib; });

  em100 = nixpkgsOnBuildForBuild.callPackage ./util/em100 { };
  flashrom = nixpkgsOnBuildForBuild.callPackage ./util/flashrom { };
}


